#
# spec file for package perl-Sysadm-Install
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Sysadm-Install
Version:        0.47
Release:        3.1
%define cpan_name Sysadm-Install
Summary:        Typical installation tasks for system administrators
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Sysadm-Install/
Source0:        http://www.cpan.org/authors/id/M/MS/MSCHILLI/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Which) >= 1.09
BuildRequires:  perl(LWP::Simple)
BuildRequires:  perl(Log::Log4perl) >= 1.28
BuildRequires:  perl(Term::ReadKey)
Requires:       perl(File::Which) >= 1.09
Requires:       perl(LWP::Simple)
Requires:       perl(Log::Log4perl) >= 1.28
Requires:       perl(Term::ReadKey)
%{perl_requires}

%description
Have you ever wished for your installation shell scripts to run
reproducibly, without much programming fuzz, and even with optional logging
enabled? Then give up shell programming, use Perl.

'Sysadm::Install' executes shell-like commands performing typical
installation tasks: Copying files, extracting tarballs, calling 'make'. It
has a 'fail once and die' policy, meticulously checking the result of every
operation and calling 'die()' immediately if anything fails.

'Sysadm::Install' also supports a _dry_run_ mode, in which it logs
everything, but suppresses any write actions. Dry run mode is enabled by
calling 'Sysadm::Install::dry_run(1)'. To switch back to normal, call
'Sysadm::Install::dry_run(0)'.

As of version 0.17, 'Sysadm::Install' supports a _confirm_ mode, in which
it interactively asks the user before running any of its functions (just
like 'rm -i'). _confirm_ mode is enabled by calling
'Sysadm::Install::confirm(1)'. To switch back to normal, call
'Sysadm::Install::confirm(0)'.

'Sysadm::Install' is fully Log4perl-enabled. To start logging, just
initialize 'Log::Log4perl'. 'Sysadm::Install' acts as a wrapper class,
meaning that file names and line numbers are reported from the calling
program's point of view.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Tue May 31 2016 coolo@suse.com
- updated to 0.47
  see /usr/share/doc/packages/perl-Sysadm-Install/Changes
  0.47  (2016/05/29)
    (ms) password_read() now writes the prompt to STDERR (instead of STDOUT), and
    optionally to /dev/tty if specified. This allows for redirecting STDOUT
    (and even STDERR) to a file without losing the password prompt.
* Sat Jun 27 2015 coolo@suse.com
- updated to 0.46
  see /usr/share/doc/packages/perl-Sysadm-Install/Changes
  0.46  (2015/06/23)
    (ms) ask() and pick() now support getting the user's response on the
    tty, instead of stdin, so they can be used from within a pipe.
* Sun Jun  7 2015 coolo@suse.com
- updated to 0.45
  see /usr/share/doc/packages/perl-Sysadm-Install/Changes
  0.45  (2015/05/25)
    (ms) Alexandr Ciornii fixed manifest and tests for the Windows platform
* Tue Sep 16 2014 coolo@suse.com
- updated to 0.44
    (ms) replaced bin_find() implementation by File::Which
    (ms) tap() with raise_error option set now dies with stderr output,
    because $! isn't set on failed close().
* Sat Jun 15 2013 coolo@suse.com
- updated to 0.43
    (ms) Using binmode() now for slurp/blurt for compatibility with Win32
    systems.
    (ms) No longer silently removing directories that are in the way
    before untar().
    (ms) Better error diagnosis on failing untar() tests
    (ms) Added home_dir() function returning user's home directory.
    (ms) tap() now supports stdout_limit and stderr_limit options to
    limit log verbosity
    (ms) Applied pull request by ks0608 to fix Cwd problem on Win32/Mac
    (https://github.com/mschilli/sysadm-install-perl/pull/1)
    (ms) Fixed bin_find, to omit directories
    (ms) Added cdback() with reset option
* Mon Aug 29 2011 detlef@links2linux.de
- new upstream version <0.38>
  (ms) Fixed Win32 test in 012tap.t
  (ms) [rt.cpan.org #68095] Applied fix by Kai von Thadden for
    tap's raise_error option and added test case.
* Mon May 23 2011 coolo@novell.com
- updated to 0.36
    (ms) Added owner_cp() to copy uid and gid of a file or directory.
    (ms) Added raise_error option for tap()
    (ms) snip() now returns original string (with unprintables replaced)
    if the data length is shorter than $maxlen.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Aug  9 2010 chris@computersalat.de
- update to 0.35
  * [RT 54885] Merged with github fork by Thomas Lenz, fixing
    blurt_atomic on Win32.
  * Fixed local caller_depth increments
  * Fixed printable() bug masking '-'.
  0.34  (2010/02/21)
  * Added github repository link to Makefile.PL
  * [RT 53324] bin_find fix for Windows using $Config::Config{path_sep}
  * [RT 54555] Fixed test suite errors on Win32
- recreated by cpanspec 1.78
  o changed to Build.PL
- noarch pkg
* Thu Dec 10 2009 chris@computersalat.de
- update to 0.33
  * utf8_available() now uses eval"" to check for Encode module,
    Sysadm::Install therefore no longer requires Encode to be installed.
  * Got rid of LWP::Simple because of its env_proxy() call at
    compile time, which freaks out on env variables like "use_proxy"
    when set to numeric values. Using LWP::UserAgent instead.
- cleanup spec
  * added header
  * sorted Tags
  * fixed deps
  * fixed description
  * added author
  * moved changelog to .changes
- added perl-macros
  * perl_gen_filelist
* Sun Aug 30 2009 detlef@links2linux.de
- new upstream release <0.32>-<0.pm.1>
* Sat Mar 29 2008 detlef@links2linux.de
- new upstream release <0.27>-<0.pm.1>
* Wed Jan  9 2008 detlef@links2linux.de
- new upstream release <0.25>-<0.pm.1>
* Mon Dec 31 2007 detlef@links2linux.de
- new upstream release <0.24>-<0.pm.1>
* Fri Apr 13 2007 detlef@links2linux.de
- new upstream release <0.23>-<0.pm.1>
* Sun Oct 15 2006 detlef@links2linux.de
- initial build for packman
